﻿//-----------------------------------------------------------------------------
// <copyright file="AddressEvent.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Specific EventArgs for changing address configuration.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// Specific EventArgs for changing address configuration.
    /// </summary>
    public class AddressEvent : EventArgs
    {
        /// <summary>
        /// Initializes a new instance of the AddressEvent class.
        /// </summary>
        /// <param name="relevantDevice">Type of the relevant device from UsbInterfaceTesttool.Devices.</param>
        /// <param name="address">New address.</param>
        public AddressEvent(Type relevantDevice, string address)
            : base()
        {
            if (address.Length == 0)
            {
                throw new ArgumentException();
            }

            this.RelevantDevice = relevantDevice;
            this.Address = new string[] { address };
        }

        /// <summary>
        /// Initializes a new instance of the AddressEvent class.
        /// </summary>
        /// <param name="relevantDevice">Type of the relevant device from UsbInterfaceTesttool.Devices.</param>
        /// <param name="address">New addresses.</param>
        public AddressEvent(Type relevantDevice, string[] address)
            : base()
        {
            this.RelevantDevice = relevantDevice;
            this.Address = address;
        }

        /// <summary>
        /// Gets or sets type of the relevant device from UsbInterfaceTesttool.Devices.
        /// </summary>
        /// <value>Type of the relevant device.</value>
        public Type RelevantDevice { get; set; }

        /// <summary>
        /// Gets or sets new addresses from GUI.
        /// </summary>
        /// <value>New addresses from GUI.</value>
        public string[] Address { get; set; }

        /// <summary>
        /// Gets the first new address.
        /// </summary>
        /// <returns>First new address.</returns>
        public string GetFirstAddress()
        {
            return this.Address[0];
        }
    }
}