﻿//-----------------------------------------------------------------------------
// <copyright file="ChartUtils.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>
// Provides static methods for reordering the data of charts.
// </summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Charts
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Windows.Forms.DataVisualization.Charting;

    /// <summary>
    /// Provides static methods for reordering the data of charts.
    /// </summary>
    public static class ChartUtils
    {
        /// <summary>
        /// Shifts all items of a SeriesCollection 1 index to the right.
        /// </summary>
        /// <param name="seriesCollection">SeriesCollection to shift.</param>
        public static void MoveSeriesPointsToRight(SeriesCollection seriesCollection)
        {
            DataPoint temp;
            foreach (Series series in seriesCollection)
            {
                for (int i = series.Points.Count - 1; i >= 0; i--)
                {
                    if (i - 1 < 0)
                    {
                        break;
                    }

                    temp = series.Points[i];
                    series.Points[i] = series.Points[i - 1];
                    series.Points[i - 1] = temp;
                }

                for (int i = 0; i < series.Points.Count; i++)
                {
                    series.Points[i].XValue = i + 1;
                }
            }
        }

        /// <summary>
        /// Updates the minimum and maximum of chart axes.
        /// </summary>
        /// <param name="chart">The chart to manipulate.</param>
        /// <param name="isHighResolutionModeEnabled">Indicates whether high resolution mode is enabled or not.</param>
        public static void UpdateChartAxes(Chart chart, bool isHighResolutionModeEnabled)
        {
            if (isHighResolutionModeEnabled)
            {
                chart.ChartAreas[0].AxisY.Maximum = 2200;
                chart.ChartAreas[0].AxisY.Minimum = -2100;

                chart.ChartAreas[0].AxisY.Interval = 1050;
            }
            else
            {
                chart.ChartAreas[0].AxisY.Maximum = 550;
                chart.ChartAreas[0].AxisY.Minimum = -550;

                chart.ChartAreas[0].AxisY.Interval = 275;
            }
        }
    }
}
