﻿//-----------------------------------------------------------------------------
// <copyright file="AddressSettingsConverter.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Determines which control for chosing an address is visible to the user.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Converter
{
    using System;
    using System.Windows;
    using System.Windows.Controls;
    using System.Windows.Data;

    /// <summary>
    /// Determines which control for chosing an address is visible to the user.
    /// </summary>
    public class AddressSettingsConverter : IValueConverter
    {
        #region IValueConverter Member
        /// <summary>
        /// Converts the current visible control to a visibility.
        /// </summary>
        /// <param name="value">Used control.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">Address choser which gets the visibility.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>Calculated visibility.</returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (!(value is Control))
            {
                throw new ArgumentException("the binded value must be a control");
            }
            else if (!(parameter is string))
            {
                throw new ArgumentException("the parameter must be a string");
            }

            string tag = (value as Control).Tag.ToString();
           
            switch (tag)
            {
                case "common":
                    return Visibility.Collapsed;

                case "3D-BS":
                    if (App.UsbInterfaceType == UsbInterfaceTesttool.SerialCommunication.UsbInterface.Type.SPI &&
                        parameter as string == "setSpiDefault")
                    {
                        return Visibility.Visible;
                    }

                    break;

                case "6D-BS":
                    if (App.UsbInterfaceType == UsbInterfaceTesttool.SerialCommunication.UsbInterface.Type.SPI &&
                        parameter as string == "setSpi6DBS")
                    {
                        return Visibility.Visible;
                    }

                    break;

                case "RTC":
                    if (App.UsbInterfaceType == UsbInterfaceTesttool.SerialCommunication.UsbInterface.Type.SPI &&
                        parameter as string == "setSpiDefault")
                    {
                        return Visibility.Visible;
                    }

                    break;

                default:
                    throw new ArgumentException(string.Format("{0} is a unknown tag", tag));
            }

            return Visibility.Collapsed;
        }

        /// <summary>
        /// The method is not used.
        /// </summary>
        /// <param name="value">The parameter is not used.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">The parameter is not used.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>The parameter is not used.</returns>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
        #endregion
    }
}
