﻿//-----------------------------------------------------------------------------
// <copyright file="BooleanToSpiAddressConverter.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Used in address choser for chosing a unique spi address for two devices. Converts the spi addresses in bool values for radio buttons.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Converter
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Windows.Data;
    using UsbInterfaceTesttool.SerialCommunication;

    /// <summary>
    /// Used in address choser for chosing a unique spi address for two devices. Converts the spi addresses in a bool value for radio buttons.
    /// </summary>
    public class BooleanToSpiAddressConverter : IValueConverter
    {
        #region IValueConverter Member
        /// <summary>
        /// Converts the spi addresses in a bool value for radio buttons.
        /// </summary>
        /// <param name="value">New spi address.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">RadioButton option.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>Bool value for radio buttons.</returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            UsbInterface.SpiAddress spiAddress = (UsbInterface.SpiAddress)value;

            bool shouldInvert = parameter.ToString() == "B";
            if (spiAddress == UsbInterface.SpiAddress.A)
            {
                if (shouldInvert)
                {
                    return false;
                }
                else
                {
                    return true;
                }
            }
            else
            {
                if (shouldInvert)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        /// <summary>
        /// Converts the bool address in a spi address.
        /// </summary>
        /// <param name="value">Checked state of the radio button.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">Spi address as string.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>The parameter is not used.</returns>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            bool controlChecked = (bool)value;
            if (controlChecked)
            {
                if (parameter.ToString() == "A")
                {
                    return UsbInterface.SpiAddress.A;
                }
                else
                {
                    return UsbInterface.SpiAddress.B;
                }
            }
            else
            {
                if (parameter.ToString() == "A")
                {
                    return UsbInterface.SpiAddress.B;
                }
                else
                {
                    return UsbInterface.SpiAddress.A;
                }
            }
        }
        #endregion
    }
}
