﻿//-----------------------------------------------------------------------------
// <copyright file="DeviceToVisibilityConverter.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Shows the GUI-interface of a supported device based on the chosen interface type.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Converter
{
    using System;
    using System.Linq;
    using System.Windows;
    using System.Windows.Data;
    using UsbInterfaceTesttool.Devices;

    /// <summary>
    /// Shows the GUI-interface of a supported device based on the chosen interface type.
    /// </summary>
    public class DeviceToVisibilityConverter : IValueConverter
    {
        #region IValueConverter Member
        /// <summary>
        /// Converts the name of a supported device to visibility for its GUI-elements.
        /// </summary>
        /// <param name="value">Name of a supported device.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">The parameter is not used.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>Calculated visibility.</returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            string register = parameter.ToString();
            Type type;
            switch (register)
            {
                case "common":
                    return Visibility.Visible;
                case "3D-BS":
                    type = typeof(_3DBS);
                    break;
                case "6D-BS":
                    type = typeof(_6DBS);
                    break;
                case "RTC":
                    type = typeof(_RTC);
                    break;
                default:
                    throw new ArgumentException();
            }

            foreach (object o in type.GetCustomAttributes(false))
            {
                if (o is Supports)
                {
                    Supports supports = (Supports)o;

                    if ((o as Supports).SupportedTypes.Contains(App.UsbInterfaceType))
                    {
                        return Visibility.Visible;
                    }
                    else
                    {
                        return Visibility.Hidden;
                    }
                }
            }

            throw new InvalidOperationException();
        }

        /// <summary>
        /// The method is not used.
        /// </summary>
        /// <param name="value">The parameter is not used.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">The parameter is not used.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>The parameter is not used.</returns>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
        #endregion
    }
}
