﻿//-----------------------------------------------------------------------------
// <copyright file="EnumToIntConverter.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Converts a enum value to a int and back.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Converter
{
    using System;
    using System.IO.Ports;
    using System.Windows.Data;
    using UsbInterfaceTesttool.Devices;

    /// <summary>
    /// Converts a enum value to a int and back.
    /// </summary>
    public class EnumToIntConverter : IValueConverter
    {
        #region IValueConverter Member
        /// <summary>
        /// Converts a enum value to a int.
        /// </summary>
        /// <param name="value">Enum value.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">The parameter is not used.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>Casted int value.</returns>
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return (int)value;
        }

        /// <summary>
        /// Converts a int to a enum value.
        /// </summary>
        /// <param name="value">Int value to convert.</param>
        /// <param name="targetType">The parameter is not used.</param>
        /// <param name="parameter">Name of the enum.</param>
        /// <param name="culture">The parameter is not used.</param>
        /// <returns>Casted enum value.</returns>
        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            switch (parameter.ToString())
            {
                case "Parity":
                    return (Parity)((int)value);
                case "StopBits":
                    return (StopBits)((int)value);

                case "InterfaceBaudRate":
                    return (GeneralTasks.InterfaceBaudRate)((int)value);
                case "SpiClockRate":
                    return (GeneralTasks.SpiClockRate)((int)value);

                case "3DBS_Range":
                    return (_3DBS.Range)((int)value);
                case "3DBS_Bandwidth":
                    return (_3DBS.Bandwidth)((int)value);
                case "3DBS_Counter":
                    return (_3DBS.Counter)((int)value);
                case "3DBS_AnyMotionDur":
                    return (_3DBS.AnyMotionDuration)((int)value);
                case "3DBS_WakeUpPause":
                    return (_3DBS.WakeUpPause)((int)value);

                case "GyroFullScale":
                    return (UsbInterfaceTesttool.Devices._6DBS_Gyro.FullScale)((int)value);
                case "EndianSelection":
                    return (UsbInterfaceTesttool.Devices._6DBS.EndianSelection)((int)value);
                case "GyroBlockDataUpdate":
                    return (UsbInterfaceTesttool.Devices._6DBS_Gyro.BlockDataUpdate)((int)value);
                case "GyroSim":
                    return (UsbInterfaceTesttool.Devices._6DBS_Gyro.Sim)((int)value);
                case "DataFilter":
                    return (UsbInterfaceTesttool.Devices._6DBS_Gyro.DataFilter)((int)value);
                case "FilterMode":
                    return (UsbInterfaceTesttool.Devices._6DBS.FilterMode)((int)value);
                case "GyroDataFilter":
                    return (UsbInterfaceTesttool.Devices._6DBS_Gyro.DataFilter)((int)value);
                case "AccDataRate":
                    return (UsbInterfaceTesttool.Devices._6DBS_Acc.DataRate)((int)value);
                case "AccFullScale":
                    return (UsbInterfaceTesttool.Devices._6DBS_Acc.FullScale)((int)value);
                case "AccSpiMode":
                    return (UsbInterfaceTesttool.Devices._6DBS_Acc.SpiMode)((int)value);

                case "RtcPeriodicalInterruptFrequency":
                    return (UsbInterfaceTesttool.Devices._RTC.PeriodicalInterruptFrequency)((int)value);
                default:
                    throw new ArgumentException();
            }
        }
        #endregion
    }
}