﻿//-----------------------------------------------------------------------------
// <copyright file="Device.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Base class for device wrapper.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Devices
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using UsbInterfaceTesttool.SerialCommunication;

    /// <summary>
    /// Base class for device wrapper.
    /// </summary>
    public abstract class Device
    {
        /// <summary>
        /// Initializes a new instance of the Device class.
        /// </summary>
        /// <param name="usbInterface">Used USB-Interface for communication.</param>
        public Device(UsbInterface usbInterface)
        {
            this.UsbInterface = usbInterface;
        }

        /// <summary>
        /// Gets or sets address (f.e. I2C or SPI) for communication.
        /// </summary>
        /// <value>Address (f.e. I2C or SPI) for communication.</value>
        public string Address { get; protected set; }

        /// <summary>
        /// Gets or sets used USB-Interface for communication.
        /// </summary>
        /// <value>Used USB-Interface for communication.</value>
        protected UsbInterface UsbInterface { get; set; }

        /// <summary>
        /// Handles chaning addresses for the device.
        /// </summary>
        /// <param name="sender">Standard parameter sender.</param>
        /// <param name="e">Standard parameter e.</param>
        public abstract void AddressChanged(object sender, AddressEvent e);
    }
}