﻿//-----------------------------------------------------------------------------
// <copyright file="Supports.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Reflection flag for indicating which USB-interfaces a device supports.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Devices
{
    using System;
    using System.Reflection;
    using UsbInterfaceTesttool.SerialCommunication;

    /// <summary>
    /// Reflection flag for indicating which USB-interfaces a device supports.
    /// </summary>
    [AttributeUsage(AttributeTargets.Class)]
    public class Supports : System.Attribute
    {
        /// <summary>
        /// Initializes a new instance of the Supports class.
        /// </summary>
        /// <param name="supportedType">Supported device type.</param>
        public Supports(UsbInterface.Type supportedType)
        {
            this.SupportedTypes = new UsbInterface.Type[] { supportedType };
        }

        /// <summary>
        /// Initializes a new instance of the Supports class.
        /// </summary>
        /// <param name="supportedTypes">Supported device types.</param>
        public Supports(UsbInterface.Type[] supportedTypes)
        {
            this.SupportedTypes = supportedTypes;
        }

        /// <summary>
        /// Gets or sets all supported USB-interface types of a device.
        /// </summary>
        /// <value>All supported USB-interface types of a device.</value>
        public UsbInterface.Type[] SupportedTypes { get; set; }
    }
}