﻿//-----------------------------------------------------------------------------
// <copyright file="_3DBS_Settings.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Wrapper for settings of 3D-BS.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Devices
{
    using System;
    using System.Collections;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// Wrapper for settings of 3D-BS.
    /// </summary>
    public class _3DBS_Settings
    {
        /// <summary>
        /// Initializes a new instance of the _3DBS_Settings class.
        /// </summary>
        public _3DBS_Settings()
        {
            this.OperationalSettings = new Operational();
        }

        /// <summary>
        /// Gets or sets settings for operational registers.
        /// </summary>
        /// <value>Settings for operational registers.</value>
        public _3DBS_Settings.Operational OperationalSettings { get; set; }

        /// <summary>
        /// Gets or sets settings for interrupt registers.
        /// </summary>
        /// <value>Settings for interrupt registers.</value>
        public _3DBS_Settings.Interrupt InterruptSettings { get; set; }

        /// <summary>
        /// Gets or sets settings for control registers.
        /// </summary>
        /// <value>Settings for control registers.</value>
        public _3DBS_Settings.Control ControlSettings { get; set; }

        /// <summary>
        /// Gets or sets settings for status registers.
        /// </summary>
        /// <value>Settings for status registers.</value>
        public _3DBS_Settings.Status StatusSettings { get; set; }

        /// <summary>
        /// Gets or sets settings for info registers.
        /// </summary>
        /// <value>Settings for info registers.</value>
        public _3DBS_Settings.Info InfoSettings { get; set; }

        /// <summary>
        /// Settings for operational registers.
        /// </summary>
        public struct Operational
        {
            /// <summary>
            /// Gets or sets set range.
            /// </summary>
            /// <value>Set range.</value>
            public _3DBS.Range Range { get; set; }

            /// <summary>
            /// Gets or sets set bandwidth.
            /// </summary>
            /// <value>Set bandwidth.</value>
            public _3DBS.Bandwidth Bandwidth { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether the Wake_up flag is set or not.
            /// </summary>
            /// <value>A value indicating whether the Wake_up flag is set or not.</value>
            public bool Wake_up { get; set; }

            /// <summary>
            /// Gets or sets set wake up pause.
            /// </summary>
            /// <value>Set wake up pause.</value>
            public _3DBS.WakeUpPause Wake_up_pause { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether the Shadow_dis flag is set or not.
            /// </summary>
            /// <value>A value indicating whether the Shadow_dis flag is set or not.</value>
            public bool Shadow_dis { get; set; }
        }

        /// <summary>
        /// Settings for interrupt registers.
        /// </summary>
        public struct Interrupt
        {
            /// <summary>
            /// Gets or sets a value indicating whether EnableLG flag is set or not.
            /// </summary>
            /// <value>A value indicating whether EnableLG flag is set or not.</value>
            public bool EnableLG { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether EnableHG flag is set or not.
            /// </summary>
            /// <value>A value indicating whether EnableHG flag is set or not.</value>
            public bool EnableHG { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether EnableAdvINT flag is set or not.
            /// </summary>
            /// <value>A value indicating whether EnableAdvINT flag is set or not.</value>
            public bool EnableAdvINT { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether AnyMotion flag is set or not.
            /// </summary>
            /// <value>A value indicating whether AnyMotion flag is set or not.</value>
            public bool AnyMotion { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Alert flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Alert flag is set or not.</value>
            public bool Alert { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether LatchINT flag is set or not.
            /// </summary>
            /// <value>A value indicating whether LatchINT flag is set or not.</value>
            public bool LatchINT { get; set; }

            /// <summary>
            /// Gets or sets LG_thres value.
            /// </summary>
            /// <value>LG_thres value.</value>
            public BitArray LGThres { get; set; }

            /// <summary>
            /// Gets or sets LG_hyst value.
            /// </summary>
            /// <value>LG_hyst value.</value>
            public BitArray LGHyst { get; set; }

            /// <summary>
            /// Gets or sets LG_dur, value.
            /// </summary>
            /// <value>LG_dur, value.</value>
            public BitArray LGDur { get; set; }

            /// <summary>
            /// Gets or sets counter_LG value.
            /// </summary>
            /// <value>Counter_LG value.</value>
            public _3DBS.Counter CounterLG { get; set; }

            /// <summary>
            /// Gets or sets HG_thres value.
            /// </summary>
            /// <value>HG_thres value.</value>
            public BitArray HGThres { get; set; }

            /// <summary>
            /// Gets or sets HG_hyst value.
            /// </summary>
            /// <value>HG_hyst value.</value>
            public BitArray HGHyst { get; set; }

            /// <summary>
            /// Gets or sets HG_dur, value.
            /// </summary>
            /// <value>HG_dur, value.</value>
            public BitArray HGDur { get; set; }

            /// <summary>
            /// Gets or sets counter_HG value.
            /// </summary>
            /// <value>Counter_HG value.</value>
            public _3DBS.Counter CounterHG { get; set; }

            /// <summary>
            /// Gets or sets Any_motion_thres value.
            /// </summary>
            /// <value>Any_motion_thres value.</value>
            public BitArray AnyMotionThres { get; set; }

            /// <summary>
            /// Gets or sets number of required consecutive conditions to set or reset the any motion interrupt.
            /// </summary>
            /// <value>Number of required consecutive conditions to set or reset the any motion interrupt.</value>
            public _3DBS.AnyMotionDuration AnyMotionDuration { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether New_data_int flag is set or not.
            /// </summary>
            /// <value>A value indicating whether New_data_int flag is set or not.</value>
            public bool NewDataInt { get; set; }
        }

        /// <summary>
        /// Settings for control registers.
        /// </summary>
        public struct Control
        {
            /// <summary>
            /// Gets or sets a value indicating whether Reset_INT flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Reset_INT flag is set or not.</value>
            public bool ResetINT { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Selftest_0 flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Selftest_0 flag is set or not.</value>
            public bool Selftest0 { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Selftest_1 flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Selftest_1 flag is set or not.</value>
            public bool Selftest1 { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Soft_reset flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Soft_reset flag is set or not.</value>
            public bool SoftReset { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Sleep flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Sleep flag is set or not.</value>
            public bool Sleep { get; set; }
        }

        /// <summary>
        /// Settings for status registers.
        /// </summary>
        public struct Status
        {
            /// <summary>
            /// Gets or sets a value indicating whether St_result flag is set or not.
            /// </summary>
            /// <value>A value indicating whether St_result flag is set or not.</value>
            public bool StResult { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Alert_phase flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Alert_phase flag is set or not.</value>
            public bool AlertPhase { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether LG_latched flag is set or not.
            /// </summary>
            /// <value>A value indicating whether LG_latched flag is set or not.</value>
            public bool LGlatched { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether HG_latched flag is set or not.
            /// </summary>
            /// <value>A value indicating whether HG_latched flag is set or not.</value>
            public bool HGlatched { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether Status_LG flag is set or not.
            /// </summary>
            /// <value>A value indicating whether Status_LG flag is set or not.</value>
            public bool StatusLG { get; set; }

            /// <summary>
            /// Gets or sets a value indicating whether status_HG flag is set or not.
            /// </summary>
            /// <value>A value indicating whether status_HG flag is set or not.</value>
            public bool StatusHG { get; set; }
        }

        /// <summary>
        /// Settings for info registers.
        /// </summary>
        public struct Info
        {
            /// <summary>
            /// Gets or sets Al_version value.
            /// </summary>
            /// <value>Al_version value.</value>
            public BitArray AiVersion { get; set; }

            /// <summary>
            /// Gets or sets ml_version value.
            /// </summary>
            /// <value>Ml_version value.</value>
            public BitArray MlVersion { get; set; }

            /// <summary>
            /// Gets or sets ChipID value.
            /// </summary>
            /// <value>ChipID value.</value>
            public BitArray ChipID { get; set; }
        }
    }
}