﻿//-----------------------------------------------------------------------------
// <copyright file="EditSerialPortSettingsWindow.xaml.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Window for setting connection settings for a ComPort.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool
{
    using System.Windows;
    using UsbInterfaceTesttool.SerialCommunication;

    /// <summary>
    /// Window for setting connection settings for a ComPort.
    /// </summary>
    public partial class EditSerialPortSettingsWindow : Window
    {
        /// <summary>
        /// Current connection settings for a ComPort.
        /// </summary>
        public readonly SerialPortSettings SerialPortSettings;

        /// <summary>
        /// Initializes a new instance of the EditSerialPortSettingsWindow class.
        /// </summary>
        /// <param name="serialPortSettings">Current connection settings for a ComPort.</param>
        public EditSerialPortSettingsWindow(SerialPortSettings serialPortSettings)
            : base()
        {
            this.InitializeComponent();

            this.SerialPortSettings = new SerialPortSettings()
            {
                BaudRate = serialPortSettings.BaudRate,
                DataBits = serialPortSettings.DataBits,
                Parity = serialPortSettings.Parity,
                StopBits = serialPortSettings.StopBits
            };

            this.DataContext = this.SerialPortSettings;
        }

        /// <summary>
        /// Closes the window with success.
        /// </summary>
        /// <param name="sender">Standard parameter sender.</param>
        /// <param name="e">Standard parameter e.</param>
        private void CloseSuccess_Click(object sender, RoutedEventArgs e)
        {
            this.DialogResult = true;
            this.Close();
        }

        /// <summary>
        /// Closes the window with failure.
        /// </summary>
        /// <param name="sender">Standard parameter sender.</param>
        /// <param name="e">Standard parameter e.</param>
        private void CloseDiscard_Click(object sender, RoutedEventArgs e)
        {
            this.DialogResult = false;
            this.Close();
        }
    }
}