﻿//-----------------------------------------------------------------------------
// <copyright file="ChartUtils.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>
// Provides static methods for reordering the data of charts.
// </summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Charts
{
    using System.Drawing;
    using System.Windows.Forms.DataVisualization.Charting;

    /// <summary>
    /// Provides static methods for reordering the data of charts.
    /// </summary>
    public static class ChartUtils
    {
        /// <summary>
        /// Shifts all items of a SeriesCollection 1 index to the right.
        /// </summary>
        /// <param name="seriesCollection">SeriesCollection to shift.</param>
        public static void MoveSeriesPointsToRight(SeriesCollection seriesCollection)
        {
            DataPoint temp;
            foreach (Series series in seriesCollection)
            {
                for (int i = series.Points.Count - 1; i >= 0; i--)
                {
                    if (i - 1 < 0)
                    {
                        break;
                    }

                    temp = series.Points[i];
                    series.Points[i] = series.Points[i - 1];
                    series.Points[i - 1] = temp;
                }

                for (int i = 0; i < series.Points.Count; i++)
                {
                    series.Points[i].XValue = i + 1;
                }
            }
        }

        /// <summary>
        /// Updates the minimum and maximum of chart axes.
        /// </summary>
        /// <param name="chart">The chart to manipulate.</param>
        /// <param name="isHighResolutionModeEnabled">Indicates whether high resolution mode is enabled or not.</param>
        public static void UpdateChartAxes(Chart chart, bool isHighResolutionModeEnabled)
        {
            if (isHighResolutionModeEnabled)
            {
                chart.ChartAreas[0].AxisY.Maximum = 2200;
                chart.ChartAreas[0].AxisY.Minimum = -2100;

                chart.ChartAreas[0].AxisY.Interval = 1050;
            }
            else
            {
                chart.ChartAreas[0].AxisY.Maximum = 550;
                chart.ChartAreas[0].AxisY.Minimum = -550;

                chart.ChartAreas[0].AxisY.Interval = 275;
            }
        }

        /// <summary>
        /// Initialize a chart.
        /// </summary>
        /// <param name="chart">Chart to initialize.</param>
        /// <param name="amplitude">Amplitude of the chart.</param>
        public static void InitChart(Chart chart, int amplitude)
        {
            const int MaximalPoints = 50;

            if (chart.ChartAreas.Count == 0)
            {
                chart.ChartAreas.Add(new ChartArea());
            }

            chart.Series.Clear();
            chart.Series.Add("X");
            chart.Series.Add("Y");
            chart.Series.Add("Z");
            foreach (Series item in chart.Series)
            {
                item.ChartType = SeriesChartType.Line;
            }

            chart.ChartAreas[0].AxisX.MinorGrid.Interval = 5;
            chart.ChartAreas[0].AxisX.Minimum = 0;
            chart.ChartAreas[0].AxisX.Maximum = MaximalPoints;

            chart.ChartAreas[0].AxisY.MinorGrid.Interval = 1000;
            chart.ChartAreas[0].AxisY.Minimum = -amplitude;
            chart.ChartAreas[0].AxisY.Maximum = amplitude;

            foreach (Series series in chart.Series)
            {
                for (int i = 1; i < MaximalPoints + 1; i++)
                {
                    series.Points.AddXY(i, 0.0);
                }
            }

            chart.Series[0].Color = Color.Red;
            chart.Series[1].Color = Color.Green;
            chart.Series[2].Color = Color.Blue;

            foreach (var legend in chart.Legends)
            {
                legend.BackColor = Color.Transparent;
            }

            foreach (var area in chart.ChartAreas)
            {
                area.BackColor = Color.Transparent;
            }

            chart.BackColor = Color.Transparent;
        }
    }
}
