﻿//-----------------------------------------------------------------------------
// <copyright file="ErrorUtils.cs" company="eQ-3 Entwicklung GmbH">
//  Copyright (c) 2013 eQ-3 Entwicklung GmbH
// </copyright>
// <summary>Utility methods for showing errors.</summary>
//-----------------------------------------------------------------------------
namespace UsbInterfaceTesttool.Utils
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using System.Threading;
    using System.Windows.Forms;

    /// <summary>
    /// Utility methods for showing errors.
    /// </summary>
    public static class ErrorUtils
    {
        /// <summary>
        /// Lock-object for displaying only one message box at the same time.
        /// </summary>
        private static object messageBoxLocker = new object();

        /// <summary>
        /// Shows an exception in a message box.
        /// </summary>
        /// <param name="ex">Exception to show.</param>
        public static void Show(Exception ex)
        {
            ErrorUtils.Show(ex.Message);
        }

        /// <summary>
        /// Shows a error message in a message box.
        /// </summary>
        /// <param name="message">Error message to show.</param>
        public static void Show(string message)
        {
            if (!Monitor.TryEnter(messageBoxLocker, 0))
            {
                return;
            }

            lock (messageBoxLocker)
            {
                var result = MessageBox.Show(message, "Fehler", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}
